Module c_jets

Module c_jets 

FFI related to jets

Re-exports

pub use c_env::elements;
pub use c_frame::byte_width;
pub use c_frame::uword_width;
pub use frame_ffi::CFrameItem;
pub use jets_ffi as elements_ffi;

Modules

c_env
c_frame
High level APIs to creating read/write CFrames
frame_ffi
Frame related FFI bindings and data structures
jets_ffi
jets_wrapper

Functions

sanity_check_report
sanity_checks
sanity checks for using the types. We are not using the internal representation of the types at all, but we do care about the size and alignments of the types.